@@ -33,6 +33,8 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
+#include <errno.h>
+#include <pthread.h>
 #include <dlfcn.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -111,13 +113,12 @@
 
 #define START_FUNCTION        fprintf(stderr,"\n>>>>>>>>>Start %s()\n", __PRETTY_FUNCTION__);
 #define END_FUNCTION		fprintf(stderr,"\n>>>>>>>>>End %s()\n", __PRETTY_FUNCTION__);
-
+#define DEBUG_FUNCTION(string)  write_log(string)
 /*
 #define START_FUNCTION          FILE *f; f=fopen("/tmp/omw.log","a+"); fprintf(f,"\n>>>>>>>>>Start %s()\n", __PRETTY_FUNCTION__);fflush(f);fclose(f);
-#define DEBUG_FUNCTION(string)  write_log(string)
 #define END_FUNCTION          FILE *fileend; fileend=fopen("/tmp/omw.log","a+"); fprintf(fileend,"\n>>>>>>>>>End %s()\n", __PRETTY_FUNCTION__);fflush(fileend);fclose(fileend);
-
 */
+
 #define OMWEATHER_ADD_STATION           1000
 #define OMWEATHER_SEARCH_STATION        1001
 #define OMWEATHER_CLOSE_STATION_WINDOW  1002
@@ -136,6 +137,12 @@
 /*******************************************************************************/
 enum { AUTOUPDATE, CHANGE_DAY_PART, DBUSINITEVENT, UPDATE_AFTER_CONNECTED,
        CHECK_GPS_POSITION};
+enum { DOWNLOAD_UNCKNOWN_ERROR = -1, DOWNLOAD_OK = 0, DOWNLOAD_PROXY_ERROR = 5,
+        DOWNLOAD_RESOLVE_ERROR = 6, DOWNLOAD_CONNECT_ERROR = 7,
+        DOWNLOAD_ACCESS_DENIED = 9, DOWNLOAD_HTTP_ERROR = 22,
+        DOWNLOAD_NOW_WORKING = 50, DOWNLOAD_FINISHED = 51,
+        DOWNLOAD_TIMEOUT = 28, DOWNLOAD_WAKEUP_CONNECTION_FAILED = 52 };
+
 enum { UNKNOWN_DIRECTION, TO_NORTH, TO_NORTH_EAST, TO_EAST, TO_SOUTH_EAST, TO_SOUTH, TO_SOUTH_WEST, TO_WEST, TO_NORTH_WEST };
 enum { ONE_ROW, ONE_COLUMN, TWO_ROWS, TWO_COLUMNS, COMBINATION, PRESET_NOW, PRESET_NOW_PLUS_TWO, PRESET_NOW_PLUS_THREE_V,
        PRESET_NOW_PLUS_THREE_H, PRESET_NOW_PLUS_SEVEN, APPLICATION_MODE };
@@ -151,6 +158,7 @@ enum { WEATHER_COM, RP5_RU, MAX_WEATHER_SOURCE_NUMBER };
 enum { TINY_ICON_SIZE = 32, SMALL_ICON_SIZE = 48, MEDIUM_ICON_SIZE = 64,
        BIG_ICON_SIZE = 80, LARGE_ICON_SIZE = 96, GIANT_ICON_SIZE = 128,
        SUPER_GIANT_ICON_SIZE = 256};
+enum { ZERO_PHASE = -1, FIRST_PHASE = 0, SECOND_PHASE, THIRD_PHASE, FOURTH_PHASE, FIFTH_PHASE, SIXTH_PHASE };
 enum { SETTINGS_STATIONS_PAGE, SETTINGS_VISUALS_PAGE, SETTINGS_DISPLAY_PAGE,
        SETTINGS_UNITS_PAGE, SETTINGS_UPDATE_PAGE,
 #if defined(OS2008) || defined(OS2009) || defined(NONMAEMO)
@@ -329,21 +337,83 @@ typedef struct applet_config{
     gboolean    is_application_mode;
     gboolean	update_gsm;
     gboolean	update_wlan;
+    gboolean	animation;
     gint	view_mode;
 }AppletConfig;
 /*******************************************************************************/
-#ifdef CLUTTER
+#if defined CLUTTER || defined OS2009
 typedef struct SuperOH{
+#if defined CLUTTER 
+  ClutterTimeline       *timeline;
   ClutterActor          *icon;
   ClutterGroup          *group;
   ClutterActor          *stage;
   ClutterScript         *script;
-  ClutterTimeline       *timeline;
+  ClutterActor          *bgtex;
+#else
+  gint                  timeline;
+#endif
+  GtkWidget             *image; /* Temp */
+  gpointer              *function;
   GtkWidget             *clutter;
   GtkWidget             *icon_widget;
+  GtkWidget             *window;
   GdkPixbuf             *bgpixb;
-  ClutterActor          *bgtex;
+  GSList                *list_images;
+  guint                 runtime;
+  guint                 merge_id;
+  guint                 duration;
+  guint                 delay;
+  gint                  icon_size;
+  gchar                 *icon_name;
+  gboolean              first_icon_in_list;
 }SuperOH;
+#endif
+#ifdef HILDONANIMATION
+#define LOAD_ACTOR 1
+#define POSITION_ACTOR 2
+#define OPACITY_ACTOR 3
+#define SCALE_ACTOR 4
+#define ROTATE_ACTOR 5
+typedef struct Event{
+    gchar       *event_type;
+    gpointer    event;
+    GtkWidget   *image;
+    gint        number;
+}Event;
+/* Event for load actor */            
+typedef struct Event_l{
+  gchar                 *name;
+  gint                  height;
+  gint                  width;
+}Event_l;
+/* Event for changed Position of actor */            
+typedef struct Event_p{
+  gint                  x;
+  gint                  y;
+}Event_p;
+/* Event for changed Opacity of actor */            
+typedef struct Event_o{
+  gint                  o;
+}Event_o;
+/* Event for changed Scale of actor */            
+typedef struct Event_s{
+  gdouble               x;
+  gdouble               y;
+}Event_s;
+/* Event for changed Rotate of actor */            
+typedef struct Event_r{
+  gdouble               a;
+  gint                  x;
+  gint                  y;
+  gint                  z;
+  gint                  d;
+}Event_r;
+
+
+
+
+
 #endif
 /*******************************************************************************/
 typedef struct OMWeatherApplet{
@@ -396,6 +466,7 @@ typedef struct OMWeatherApplet{
     gint		sources_number;
     GtkWidget 		*contextmenu;
     gboolean 		widget_first_start;
+    gint                phase;
     gint 		widget_showing;
     gboolean 		home_item_flag_expose;
     gboolean 		area_button_pressed;
@@ -436,6 +507,7 @@ typedef struct OMWeatherApplet{
 #endif
 #ifdef OS2009
     gboolean    portrait_position;
+    HDHomePluginItem *home_window;
 #endif
 #if defined(OS2008) || defined(DEBUGTEMP) || defined(OS2009)
     gfloat		sensor_data;
@@ -449,6 +521,10 @@ typedef struct OMWeatherApplet{
 #ifdef CLUTTER
     ClutterScript       *clutter_script; /* Maybe it need be deleting */
 #endif
+#ifdef HILDONANIMATION
+    GHashTable          *animation_hash; 
+#endif
+    pthread_t           update_thread_id;
 }OMWeatherApp;
 /*******************************************************************************/
 typedef struct lists_struct{
